==========
User Guide
==========

Exploring the topics listed below should give you an idea of how to use the tools provided in this library. If anything remains unclear, please feel free to open an `issue on GitHub`_ or reach out to :doc:`the author </author>`.

.. toctree::
    :maxdepth: 2

    user_guide/expression_basics
    user_guide/table_basics

The user guide is a work in progress, with more to come soon!


.. _issue on GitHub: https://github.com/welchbj/tt/issues/new
